@@ -2,7 +2,7 @@ use MooseX::Declare;
 
 class TSQL::AST {
 
-use 5.014;
+use 5.010;
 use warnings;
 use strict;
 
@@ -18,11 +18,11 @@ TSQL::AST - 'Abstract Syntax Tree' for TSQL.
 
 =head1 VERSION
 
-Version 0.03_012
+Version 0.01 
 
 =cut
 
-our $VERSION = '0.03_012';
+our $VERSION = '0.01';
 
 has 'script' => (
       is  => 'rw',
@@ -52,17 +52,14 @@ Parses Microsoft's Transact SQL dialect of SQL.
 
 =head1 DESCRIPTION
 
-This only provides a very 'broad brush' parse of TSQL.  
+This only provides a very broad brush parse of TSQL.  
 It aims to be accurate in what it does parse, but not to provide any great detail.
 Currently it recursively recognises the major block structure elements of TSQL.
 
 This is still *ALPHA* quality software.  It should still be a developer-only release, but I'm getting tired of those.
 If you've come looking for a full-blown TSQL parser, you're going to leave here very disappointed.
-Even when finished, this is going to leave most of your SQL unparsed.  
-It's intended to support another piece of work, which is currently only in the planning stage, and will have its
-development driven from those requirements as they materialise.
-
-Note TSQL::AST is only intended to parse syntactically valid TSQL.  
+Even when finished, this is going to leave most of your SQL unparsed.  It's simply intended to support another piece of work,
+which is currently only in the planning stage.
 
 
 =head1 DEPENDENCIES
@@ -71,8 +68,6 @@ TSQL::AST depends on the following modules:
 
 =over 4
 
-=item * L<TSQL::SplitStatement>
-
 =item * L<TSQL::Common::Regexp>
 
 =item * L<Data::Dumper>
@@ -149,7 +144,7 @@ This is the method which retrieves the AST for the script just parsed.
     
     my $ast = $sql_parser->parse( \@statements );
 
-    my $script = $ast->script();
+    my $script = $$ast->script();
     
 =back    
 
