@@ -1,33 +1,31 @@
 use MooseX::Declare;
-use warnings;
 
 class TSQL::AST::SQLBatch extends TSQL::AST::SQLFragment {
 
 use feature "switch";
 
-use TSQL::AST::Factory;
 use TSQL::AST::SQLFragment ;
 use TSQL::AST::SQLStatement ;
 use TSQL::AST::SQLStatementBlock ;
 use TSQL::AST::SQLTryCatchBlock ;
-
+use TSQL::AST::Factory;
 use TSQL::AST::SQLConditionalExpression;
 use TSQL::AST::SQLIfStatement;
-use TSQL::AST::SQLWhileStatement;
+
+use TSQL::Common::Regexp;
 
 use Data::Dumper;
 
 =head1 NAME
 
-TSQL::AST::SQLBatch - Represents a Batch of TSQL statements.
+TSQL::AST::SQLBatch - Represents a TSQL Batch of statements.
 
 =head1 VERSION
 
-Version 0.03 
+Version 0.01 
 
 =cut
 
-our $VERSION = '0.03';
 
 has 'statements' => (
       is  => 'rw',
@@ -36,12 +34,16 @@ has 'statements' => (
 
 override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input ){ 
 
+    my $qr_iftoken               //= TSQL::Common::Regexp->qr_iftoken();
+    my $qr_elsetoken             //= TSQL::Common::Regexp->qr_elsetoken();
+    my $qr_whiletoken            //= TSQL::Common::Regexp->qr_whiletoken();
+
     while ( $$index <= $#{$input} ) {
         my $ln = $$input[$$index];
         my $t  = TSQL::AST::Factory->makeToken($ln) ;
         given ($t) {
             when ( defined $_ && $_->isa('TSQL::AST::Token::GO') ) { 
-                #$$index++ ;            
+                $$index++ ;            
                 last ;
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::Begin') ) {
@@ -58,13 +60,23 @@ override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input ){
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::If') ) {
                 $$index++;
-                my $block = TSQL::AST::Factory->makeIfStatement($ln);
+                my $condition = $ln;
+                $condition =~ s{$qr_iftoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;
+                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
+                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
+                my $block = TSQL::AST::SQLIfStatement->new( condition => $co ) ;            
+#                $$index++;
                 $block->parse($index,$input);
                 push @{$self->statements()}, $block;
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::While') ) {
                 $$index++;
-                my $block = TSQL::AST::Factory->makeWhileStatement($ln);
+                my $condition = $ln;
+                $condition =~ s{$qr_whiletoken}{}xmis; # s{\A \s* (?:\b while \b)}{}xmis ;
+                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
+                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
+                my $block = TSQL::AST::SQLWhileStatement->new( condition => $co ) ;            
+#                $$index++;
                 $block->parse($index,$input);
                 push @{$self->statements()}, $block;
             }                
@@ -138,7 +150,7 @@ This is the method which parses the split up SQL code from the original script.
 
 =item * C<< $batch->statements() >>
 
-Array of TSQL::AST::SQLStatement for this batch in the script just parsed.
+Array of TSQL::AST::SQLStatement for the script just parsed.
     
 =back    
 
@@ -154,7 +166,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST::SQLBatch
+    perldoc TSQL::AST
 
 
 You can also look for information at:
