@@ -1,9 +1,9 @@
 use MooseX::Declare;
-use warnings;
 
 class TSQL::AST::SQLScript extends TSQL::AST::SQLFragment {
 
 use TSQL::AST::SQLBatch;
+use 5.010;
 use Data::Dumper;
 
 =head1 NAME
@@ -12,11 +12,10 @@ TSQL::AST::SQLScript - Represents a TSQL Script.
 
 =head1 VERSION
 
-Version 0.02 
+Version 0.01 
 
 =cut
 
-our $VERSION = '0.02';
 
 has 'batches' => (
       is  => 'rw',
@@ -37,6 +36,7 @@ override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input ) {
 
 1;
 
+__DATA__
 
 __DATA__
 
@@ -104,7 +104,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST::SQLScript
+    perldoc TSQL::AST
 
 
 You can also look for information at:
