@@ -1,5 +1,4 @@
 use MooseX::Declare;
-use warnings;
 
 class TSQL::AST::SQLStatement extends TSQL::AST::SQLFragment {
 
@@ -13,7 +12,6 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.01';
 
 }
 
@@ -66,7 +64,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST::SQLStatement
+    perldoc TSQL::AST
 
 
 You can also look for information at:
