@@ -1,11 +1,9 @@
 use MooseX::Declare;
-use warnings;
 
 class TSQL::AST::SQLStatementBlock extends TSQL::AST::SQLStatement {
 
 use feature "switch";
 
-use TSQL::AST::Factory;
 use TSQL::AST::SQLFragment ;
 use TSQL::AST::SQLStatement ;
 use TSQL::AST::SQLStatementBlock ;
@@ -13,23 +11,21 @@ use TSQL::AST::SQLTryCatchBlock ;
 
 use TSQL::AST::SQLConditionalExpression;
 use TSQL::AST::SQLIfStatement;
-use TSQL::AST::SQLWhileStatement;
 
-#use TSQL::Common::Regexp;
+use TSQL::Common::Regexp;
 
 use Data::Dumper;
 
 =head1 NAME
 
-TSQL::AST::SQLStatementBlock - Represents the set of TSQL Statements within a BEGIN/END Block.
+TSQL::AST::SQLStatementBlock - Represents set of TSQL Statements with a BEGIN/END Block.
 
 =head1 VERSION
 
-Version 0.02 
+Version 0.01 
 
 =cut
 
-our $VERSION = '0.02';
 
 has 'statements' => (
       is  => 'rw',
@@ -39,6 +35,11 @@ has 'statements' => (
 
 override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
 
+    my $qr_iftoken               //= TSQL::Common::Regexp->qr_iftoken();
+    my $qr_elsetoken             //= TSQL::Common::Regexp->qr_elsetoken();
+    my $qr_whiletoken            //= TSQL::Common::Regexp->qr_whiletoken();
+
+
     while ( $$index <= $#{$input} ) {
         my $ln = $$input[$$index];
         my $t  = TSQL::AST::Factory->makeToken($ln) ;
@@ -63,13 +64,22 @@ override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::If') ) {
                 $$index++;
-                my $block = TSQL::AST::Factory->makeIfStatement($ln);
+                my $condition = $ln;
+                $condition =~ s{$qr_iftoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;$condition =~ s{\A \s* (?:\b if \b)}{}xmis ;
+                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
+                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
+                my $block = TSQL::AST::SQLIfStatement->new( condition => $co ) ;            
                 $block->parse($index,$input);
                 push @{$self->statements()}, $block;
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::While') ) {
                 $$index++;
-                my $block = TSQL::AST::Factory->makeWhileStatement($ln);
+                my $condition = $ln;
+                $condition =~ s{$qr_whiletoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;$condition =~ s{\A \s* (?:\b while \b)}{}xmis ;
+                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
+                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
+                my $block = TSQL::AST::SQLWhileStatement->new( condition => $co ) ;            
+#                $$index++;
                 $block->parse($index,$input);
                 push @{$self->statements()}, $block;
             }     
@@ -158,7 +168,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST::SQLStatementBlock
+    perldoc TSQL::AST
 
 
 You can also look for information at:
