@@ -1,5 +1,4 @@
 use MooseX::Declare;
-use warnings;
 
 class TSQL::AST::SQLTryCatchBlock extends TSQL::AST::SQLStatement {
 
@@ -13,21 +12,21 @@ use TSQL::AST::SQLTryCatchBlock ;
 
 use TSQL::AST::SQLConditionalExpression;
 use TSQL::AST::SQLIfStatement;
-use TSQL::AST::SQLWhileStatement;
+
+use TSQL::Common::Regexp;
 
 use Data::Dumper;
 
 =head1 NAME
 
-TSQL::AST::SQLTryCatchBlock - Represents a TSQL Try Catch block.
+TSQL::AST::SQLTryCatchBlock - Represents TSQL Try Catch block.
 
 =head1 VERSION
 
-Version 0.02 
+Version 0.01 
 
 =cut
 
-our $VERSION = '0.02';
 
 has 'tryBlock' => (
       is  => 'rw',
@@ -43,6 +42,10 @@ has 'catchBlock' => (
 
 override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
 
+    my $qr_iftoken               //= TSQL::Common::Regexp->qr_iftoken();
+    my $qr_elsetoken             //= TSQL::Common::Regexp->qr_elsetoken();
+    my $qr_whiletoken            //= TSQL::Common::Regexp->qr_whiletoken();
+
     my $try     = 1 ;
     my $catch   = 0;
     while ( $$index <= $#{$input} ) {
@@ -90,7 +93,12 @@ override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
             } #end begintry
             when ( defined $_ && $_->isa('TSQL::AST::Token::If') ) {
                 $$index++;
-                my $block = TSQL::AST::Factory->makeIfStatement($ln);
+                my $condition = $ln;
+                $condition =~ s{$qr_iftoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;$condition =~ s{\A \s* (?:\b if \b)}{}xmis ;
+                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
+                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
+                my $block = TSQL::AST::SQLIfStatement->new( condition => $co ) ;            
+#                $$index++;
                 $block->parse($index,$input);
                 if ( $try ) {
                     push @{$self->tryBlock()}, $block;
@@ -101,7 +109,12 @@ override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
             } #end if
             when ( defined $_ && $_->isa('TSQL::AST::Token::While') ) {
                 $$index++;
-                my $block = TSQL::AST::Factory->makeWhileStatement($ln);
+                my $condition = $ln;
+                $condition =~ s{$qr_whiletoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;$condition =~ s{\A \s* (?:\b while \b)}{}xmis ;
+                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
+                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
+                my $block = TSQL::AST::SQLWhileStatement->new( condition => $co ) ;            
+#                $$index++;
                 $block->parse($index,$input);
                 if ( $try ) {
                     push @{$self->tryBlock()}, $block;
@@ -210,7 +223,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST::SQLTryCatchBlock
+    perldoc TSQL::AST
 
 
 You can also look for information at:
