@@ -2,12 +2,14 @@ use MooseX::Declare;
 
 class TSQL::AST::SQLVariableDeclaration extends TSQL::AST::SQLFragment {
 
-use TSQL::AST::SQLIdentifier;
+#use TSQL::AST::SQLIdentifier;
+use TSQL::AST::SQLVariableName;
 use TSQL::AST::SQLDataType;
 
 has 'variableName' => (
       is  => 'rw',
-      isa => 'TSQL::AST::SQLIdentifier',
+#      isa => 'TSQL::AST::SQLIdentifier',
+      isa => 'TSQL::AST::SQLVariableName',
   );
 
 
