@@ -1,5 +1,4 @@
 use MooseX::Declare;
-use warnings;
 
 class TSQL::AST::SQLWhileStatement extends TSQL::AST::SQLStatement {
 
@@ -9,8 +8,8 @@ use TSQL::AST::SQLStatement;
 use TSQL::AST::SQLStatementBlock;
 use TSQL::AST::SQLTryCatchBlock;
 #use TSQL::AST::SQLStatementBlock;
-use TSQL::AST::SQLIfStatement;
 
+use TSQL::Common::Regexp;
 
 
 =head1 NAME
@@ -19,12 +18,10 @@ TSQL::AST::SQLWhileStatement - Represents a TSQL While Statement.
 
 =head1 VERSION
 
-Version 0.02 
+Version 0.01 
 
 =cut
 
-our $VERSION = '0.02';
-
 use feature "switch";
 
 use Data::Dumper;
@@ -45,6 +42,9 @@ has 'body' => (
 override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
 
 #    while ( $$index <= $#{$input} ) {
+        my $qr_iftoken               //= TSQL::Common::Regexp->qr_iftoken();
+        my $qr_elsetoken             //= TSQL::Common::Regexp->qr_elsetoken();
+        my $qr_whiletoken            //= TSQL::Common::Regexp->qr_whiletoken();
     
         my $ln = $$input[$$index];
         my $t = TSQL::AST::Factory->makeToken($ln);
@@ -69,25 +69,31 @@ override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
                 $$index++;
                 my $block = TSQL::AST::SQLStatementBlock->new( statements => [] ) ;
                 $block->parse($index,$input);
-                $self->body($block);                
+                push @{$self->statements()}, $block;
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::BeginTry') ) {
                 $$index++;
                 my $block = TSQL::AST::SQLTryCatchBlock->new( tryBlock => [],catchBlock => [] ) ;
                 $block->parse($index,$input);
-                $self->body($block);                
+                push @{$self->statements()}, $block;
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::If') ) {
-                $$index++;
-                my $block = TSQL::AST::Factory->makeIfStatement($ln);
+                my $condition = $ln;
+                $condition =~ s{$qr_iftoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;$condition =~ s{\A \s* (?:\b if \b)}{}xmis ;
+                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
+                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
+                my $block = TSQL::AST::SQLIfStatement->new( condition => $co ) ;            
                 $block->parse($index,$input);
-                $self->body($block);                
+                push @{$self->statements()}, $block;
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::While') ) {
                 $$index++;
-                my $block = TSQL::AST::Factory->makeWhileStatement($ln);
-                $block->parse($index,$input);
-                $self->body($block);                
+                my $condition = $ln;
+                $condition =~ s{$qr_whiletoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;$condition =~ s{\A \s* (?:\b while \b)}{}xmis ;
+                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
+                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
+                my $block = TSQL::AST::SQLWhileStatement->new( condition => $co ) ;            
+                push @{$self->statements()}, $block;
             }                
 
             default { 
@@ -160,7 +166,7 @@ This is the method which parses the split up SQL code.
 
 =item * C<< $while->condition() >>
 
-TSQL::AST::SQLConditionalExpression representing the condition clause of the While statement.
+TSQL::AST::SQLConditionalExpression representing the condtion clause of the While statement.
     
 =back    
 
@@ -187,7 +193,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST::SQLWhileStatement
+    perldoc TSQL::AST
 
 
 You can also look for information at:
